@@ -488,6 +488,26 @@ bool can_share_imodel(const alphabet& a1, const alphabet& a2)
     return a1.name == a2.name;
 }
 
+
+model_t get_smodel(const Rules& R, const std::string& model)
+{
+    map<string,pair<string,string>> smodel_states = {{"alphabet",{"alpha","a"}},
+                                                     {"branch_categories",{"branch_categories","List[Int]"}}};
+
+    try {
+        return get_model(R, "RevCTMC[a]", model, {}, smodel_states);
+    }
+    catch (myexception& e) {};
+
+    try {
+        return get_model(R, "MixtureModel[a]", model, {}, smodel_states);
+    }
+    catch (myexception& e) {};
+
+    return get_model(R, "MultiMixtureModel[a]", model, {}, smodel_states);
+}
+
+
 owned_ptr<Model> create_A_and_T_model(const Rules& R, variables_map& args, const std::shared_ptr<module_loader>& L,
                                       ostream& out_cache, ostream& out_screen, ostream& out_both, json& info,
                                       int proc_id, const string& dir)
@@ -506,7 +526,7 @@ owned_ptr<Model> create_A_and_T_model(const Rules& R, variables_map& args, const
     // 1. Get smodels for all SPECIFIED smodel names.
     for(int i=0;i<smodel_names_mapping.n_unique_items();i++)
         if (not smodel_names_mapping.unique(i).empty())
-            full_smodels[i] = get_model(R, "MultiMixtureModel[a]",smodel_names_mapping.unique(i));
+            full_smodels[i] = get_smodel(R, smodel_names_mapping.unique(i));
 
     //------------- Get alphabet names -------------------
     shared_items<string> alphabet_names_mapping = get_mapping(args, "alphabet", filename_ranges.size());
@@ -746,7 +766,7 @@ owned_ptr<Model> create_A_and_T_model(const Rules& R, variables_map& args, const
             if (smodel_names_mapping.unique(i) == "")
                 throw myexception()<<"You must specify a substitution model - there is no default substitution model for alphabet '"<<a.name<<"'";
 
-            full_smodels[i] = get_model(R, "MultiMixtureModel[a]",smodel_names_mapping.unique(i));
+            full_smodels[i] = get_smodel(R, smodel_names_mapping.unique(i));
         }
     
     // 8. Check that alignment alphabet fits requirements from smodel.
@@ -793,14 +813,18 @@ owned_ptr<Model> create_A_and_T_model(const Rules& R, variables_map& args, const
         if (args.count("branch-lengths"))
             M = args["branch-lengths"].as<string>();
         else
-            M = "~iid[num_branches[T],gamma[0.5,div[2,num_branches[T]]]]";
+            M = "~iid[num_branches[tree],gamma[0.5,div[2,num_branches[tree]]]]";
 
-        branch_length_model = get_model(R, "List[Double]", M, {{"T","Tree"}});
-        branch_length_model.expression = lambda_quantify(var("var_T"), branch_length_model.expression);
+        branch_length_model = get_model(R, "List[Double]", M, {{"tree","Tree"}});
+        branch_length_model.code.E = lambda_quantify(var("tree"), branch_length_model.code.E);
     }
 
     //-------------- Likelihood calculator types -----------//
     vector<int> likelihood_calculators(A.size(), 0);
+    for(int i=0;i<imodel_mapping.size();i++)
+        if (not imodel_mapping[i])
+            likelihood_calculators[i] = 1;
+
     if (args.count("likelihood-calculators"))
     {
         likelihood_calculators = convertTo<int>(split(args["likelihood-calculators"].as<string>(), ","));
