@@ -178,7 +178,6 @@ void show_ending_messages(bool show_only)
         extern long total_create_context1;
         extern long total_create_context2;
         extern long total_tokens;
-        extern long max_version;
         extern long total_reroot;
         extern long total_reroot_one;
         extern long total_set_reg_value;
@@ -227,7 +226,6 @@ void show_ending_messages(bool show_only)
             cout<<"  total steps scanned          = "<<total_steps_scanned<<endl;
             cout<<"  total results scanned        = "<<total_results_scanned<<endl;
             cout<<"total tokens                   = "<<total_tokens<<endl;
-            cout<<"maximum version                = "<<max_version<<endl;
             cout<<"total tokens destroyed         = "<<total_destroy_token<<endl;
             cout<<"  total knuckles destroyed     = "<<total_release_knuckle<<endl;
             cout<<"total create context           = "<<total_create_context1+total_create_context2<<endl;
@@ -331,13 +329,33 @@ std::string generate_print_program(const model_t& print, const expression_ref& a
         program_file<<"import "<<mod<<"\n";
 
     program_file<<"\n";
-    program_file<<"print_model = "<<print.expression.print()<<"\n";
-    program_file<<"\n";
-    program_file<<"alphabet = "<<a.print()<<"\n";
+    program_file<<"print_model = "<<print.code.print()<<"\n";
     program_file<<"\n";
     program_file<<"main = do\n";
-    program_file<<"  result <- run_lazy alphabet print_model\n";
-    program_file<<"  putStrLn $ show $ fst result\n";
+
+    expression_ref E = var("print_model");
+    for(auto& state_name: print.code.used_states)
+    {
+        if (state_name == "alphabet")
+            E = {E, a};
+        else if (state_name == "branch_categories")
+        {
+            throw myexception()<<"Can't handle branch categories in --print expressions right now.";
+//            smodel = {smodel, branch_categories};
+        }
+        else
+            throw myexception()<<"Don't know how to supply variable for state '"<<state_name<<"'";
+    }
+
+    if (print.code.is_action())
+        program_file<<"  result <- run_lazy (print_model alphabet)\n";
+    else
+        program_file<<"  let result = "<<E<<"\n";
+
+    if (print.code.has_loggers())
+        program_file<<"  putStrLn $ show $ fst result\n";
+    else
+        program_file<<"  putStrLn $ show $ result\n";
 
     return program_file.str();
 }
@@ -365,6 +383,8 @@ expression_ref get_alphabet_expression_from_args(const variables_map& args)
                 a = {var("triplets"),var("dna")};
             else if (alpha == "Codons")
                 a = {var("codons"),var("dna"),var("standard_code")};
+            else
+                throw myexception()<<"I don't recognize alphabet '"<<alpha<<"'";
         }
     }
     return a;
@@ -374,7 +394,7 @@ void run_print_expression(const string& argv0, variables_map& args, const shared
 {
     const string mstring = args["print"].as<string>();
     Rules R(get_package_paths(argv0, args));
-    model_t print = get_model(R,"a",mstring);
+    model_t print = get_model(R,"a",mstring,{},{{"alphabet",{"alphabet","b"}}});
 
     expression_ref a = get_alphabet_expression_from_args(args);
     {
@@ -574,7 +594,9 @@ int main(int argc,char* argv[])
                 std::cout<<table_logger_line(*TL, *M, 0)<<"\n";
             if (log_formats.count("json"))
                 std::cout<<logged_params_and_some_computed_stuff(*M, 0)<<"\n";
-            M->show_graph();
+
+            if (args.count("verbose"))
+                M->show_graph();
         }
         else 
         {
@@ -686,7 +708,16 @@ int main(int argc,char* argv[])
         retval=1;
 
         if (log_verbose > 0 and M)
-            M->show_graph();
+        {
+            try
+            {
+                M->show_graph_for_root_token();
+            }
+            catch(...)
+            {
+                err_both<<"\n\nError thrown while printing graph after catching exception!\n\n";
+            }
+        }
     }
 
     show_ending_messages(show_only);
