@@ -130,6 +130,7 @@ extern "C" closure builtin_function_register_random_variable(OperationArgs& Args
     int r_random_var = Args.current_closure().reg_for_slot(0);
 
     auto& M = Args.memory();
+    r_random_var = Args.memory().follow_index_var(r_random_var);
 
     if (auto r = Args.find_random_variable_in_root_token(r_random_var))
         r_random_var = *r;
@@ -143,6 +144,22 @@ extern "C" closure builtin_function_register_random_variable(OperationArgs& Args
     return effect;
 }
 
+extern "C" closure builtin_function_register_likelihood(OperationArgs& Args)
+{
+    // We are supposed to evaluate the likelihood before we register
+    Args.evaluate_(0);
+
+    int r_likelihood = Args.current_closure().reg_for_slot(0);
+
+    r_likelihood = Args.memory().follow_index_var(r_likelihood);
+
+    auto effect = new register_likelihood(r_likelihood);
+
+    Args.set_effect(*effect);
+
+    return effect;
+}
+
 extern "C" closure builtin_function_modifiable(OperationArgs& Args)
 {
     int r_value = Args.reg_for_slot(0);
@@ -152,21 +169,3 @@ extern "C" closure builtin_function_modifiable(OperationArgs& Args)
 
     return {mod_exp, {r_value}};
 }
-
-extern "C" closure builtin_function_register_likelihood(OperationArgs& Args)
-{
-    int R = Args.reg_for_slot(0);
-
-    int state = Args.evaluate(1).as_int();
-
-    // We are suppose to evaluate the likelihood before we register.
-    auto result_reg = Args.evaluate_slot_force(0);
-
-    auto& M = Args.memory();
-    auto likelihood = M[result_reg].exp;
-    assert(likelihood.is_log_double());
-
-    M.register_likelihood_(R);
-
-    return {EPair(state+1, constructor("()",0))};
-}
