@@ -2,17 +2,20 @@
 #include <unordered_map>
 #include "computation/machine/graph_register.H"
 #include "operations.H"
-#include "computation/expression/expression.H"
 #include "computation/expression/let.H"
 #include "computation/expression/case.H"
 #include "computation/expression/var.H"
+#include "computation/expression/resolved_symbol.H"
 #include "computation/expression/lambda.H"
 #include "computation/expression/trim.H"
+#include "computation/expression/index_var.H"
 #include "computation/expression/indexify.H"
-#include "computation/optimization/let-float.H"
+#include "computation/expression/constructor.H"
+#include "computation/expression/reg_var.H"
+#include "computation/expression/expression.H" // for is_reglike( )
 
-#include <boost/optional.hpp>
 
+using std::optional;
 using std::string;
 using std::vector;
 using std::pair;
@@ -121,12 +124,6 @@ expression_ref graph_normalize(const expression_ref& E)
 
 
 
-closure let_float(closure&& C)
-{
-    C.exp = let_float(expression_ref(C.exp));
-    return std::move(C);
-}
-
 closure graph_normalize(closure&& C)
 {
     C.exp = graph_normalize(expression_ref(C.exp));
@@ -181,21 +178,13 @@ int reg_heap::reg_for_id(const string& name)
 
 expression_ref reg_heap::translate_refs(const expression_ref& E, closure::Env_t& Env)
 {
-    int reg = -1;
+    optional<int> reg;
 
-    // Replace parameters with the appropriate reg_var: of value parameter( )
-    if (E.is_a<parameter>())
+    if (is_resolved_symbol(E))
     {
-	string name = E.as_<parameter>().parameter_name;
-
-	int param_index = find_parameter(name);
-    
-	if (param_index == -1)
-	    throw myexception()<<"Can't translate undefined parameter '"<<name<<"' in expression!";
-
-	reg = parameters[param_index].second;
+        auto& name = E.as_<resolved_symbol>().name;
+	reg = reg_for_id(name);
     }
-
     // Replace dummies that are either qualified ids, or builtin constructor names
     else if (is_qualified_var(E))
     {
@@ -212,10 +201,10 @@ expression_ref reg_heap::translate_refs(const expression_ref& E, closure::Env_t&
     else if (E.is_a<reg_var>())
 	reg = E.as_<reg_var>().target;
 
-    if (reg != -1)
+    if (reg)
     {
 	int index = Env.size();
-	Env.insert(Env.begin(), reg);
+	Env.insert(Env.begin(), *reg);
 
 	return index_var(index);
     }
