@@ -20,14 +20,23 @@
 #include "proposals.H"
 #include "tree/tree.H"
 #include "probability/probability.H"
-#include "computation/expression/expression.H"
-#include "rng.H"
-#include "util.H"
+#include "computation/expression/bool.H"
+#include "computation/expression/constructor.H"
+#include "util/rng.H"
+#include "util/mapping.H"
+#include "util/range.H"
+#include "util/set.H"
 #include "dp/dp-matrix.H"
+#include "dp/2way.H"
+#include "mcmc/sample-alignment.H"
+
+extern int log_verbose;
 
 using std::valarray;
 using std::vector;
+using std::pair;
 using std::string;
+using std::shared_ptr;
 
 valarray<double> convert_to_valarray(const vector< expression_ref >& v1)
 {
@@ -379,16 +388,9 @@ Between::Between(double m1, double m2, const proposal_fn& P)
 { }
 
 
-double reflect(const Bounds<double>& b, double x)
+double reflect(const bounds<double>& b, double x)
 {
-    if (b.has_lower_bound and b.has_upper_bound)
-	return wrap<double>(x, b.lower_bound, b.upper_bound);
-    else if (b.has_lower_bound)
-	return reflect_more_than(x, b.lower_bound);
-    else if (b.has_upper_bound)
-	return reflect_less_than(x, b.upper_bound);
-    else
-	return x;
+    return wrap<double>(x,b);
 }
 
 log_double_t Reflect::operator()(std::vector< expression_ref >& x,const std::vector<double>& p) const
@@ -397,13 +399,13 @@ log_double_t Reflect::operator()(std::vector< expression_ref >& x,const std::vec
     for(int i=0;i<x.size();i++)
     {
 	double X = x[i].as_double();
-	x[i] = reflect(bounds, X );
+	x[i] = reflect(bounds_, X );
     }
     return ratio;
 }
 
-Reflect::Reflect(const Bounds<double>& b, const proposal_fn& P)
-    :bounds(b),
+Reflect::Reflect(const bounds<double>& b, const proposal_fn& P)
+    :bounds_(b),
      proposal(P)
 { }
 
@@ -496,60 +498,7 @@ sorted::sorted(const proposal_fn& P)
     :proposal(P)
 { }
 
-log_double_t Proposal2::operator()(Model& P) const
-{
-    //  vector< expression_ref > parameters = P.get_parameter_values();
-
-    if (not indices.size())
-	throw myexception()<<"Proposal2::operator() - No parameters to alter! (all parameters fixed?)";
-
-    // Load parameter values from names
-    vector<double> p(pnames.size());
-    for(int i=0;i<p.size();i++)
-	p[i] = P.lookup_key(pnames[i]);
-
-    // read, alter, and write parameter values
-    vector< expression_ref > y = P.get_parameter_values(indices);
-    vector< expression_ref > x(y.size());
-    for(int i=0;i<x.size();i++)
-	x[i] = y[i];
-
-    auto ratio = proposal(x,p);
-
-    for(int i=0;i<y.size();i++)
-	y[i] = x[i];
-
-    P.set_parameter_values(indices,y);
-
-    return ratio;
-}
-
-Proposal2::Proposal2(const proposal_fn& p,const std::string& s, const std::vector<string>& v,
-		     const Model& P)
-    :proposal(p),
-     pnames(v)
-{
-    auto index = P.maybe_find_parameter(s);
-    if (not index)
-	throw myexception()<<"Model has no parameter called '"<<s<<"' - can't create proposal for it.";
-    indices.push_back(*index);
-}
-
-
-Proposal2::Proposal2(const proposal_fn& p,const vector<std::string>& s, const std::vector<string>& v,
-		     const Model& P)
-    :proposal(p),
-     pnames(v)
-{
-    for(int i=0;i<s.size();i++) {
-	auto index = P.maybe_find_parameter(s[i]);
-	if (not index)
-	    throw myexception()<<"Model has no parameter called '"<<s[i]<<"' - can't create proposal for it.";
-	indices.push_back(*index);
-    }
-}
-
-log_double_t Proposal2M::operator()(Model& P) const
+log_double_t Proposal2M::operator()(context_ref& P) const
 {
     if (not indices.size())
 	throw myexception()<<"Proposal2M::operator() - No modifiables to alter!";
@@ -579,44 +528,7 @@ Proposal2M::Proposal2M(const proposal_fn& p,const vector<int>& s, const vector<d
      parameters(v)
 { }
 
-log_double_t move_scale_branch(Model& /*P */)
-{
-/*
-  Parameters& PP = dynamic_cast<Parameters&>(P);
-
-  int index = PP.find_parameter("lambdaScaleBranch");
-
-  int scale_branch = PP.get_parameter_value(index).as_int();
-
-  assert( scale_branch != -1);
-
-  if (P.contains_key("lambda_search_all"))
-  scale_branch = uniform(0, PP.t().n_branches() - 1);
-  else
-  {
-  int attribute_index = PP.t().find_undirected_branch_attribute_index_by_name("lambda-scale-branch");  
-    
-  assert(attribute_index != -1);
-    
-  vector<int> branches;
-  for(int b=0;b<PP.t().n_branches();b++)
-  {
-  boost::any value = PP.t().branch(b).undirected_attribute(attribute_index);
-  if (not value.empty())
-  branches.push_back(b);
-  }
-    
-  int i = uniform(0, branches.size() -1);
-  scale_branch = branches[i];
-  }
-
-  PP.set_parameter_value(index, scale_branch);
-*/
-
-    return 1.0;
-}
-
-log_double_t move_subst_type_branch(Model& P)
+log_double_t move_subst_type_branch(context_ref& P)
 {
     Parameters& PP = dynamic_cast<Parameters&>(P);
 
@@ -624,8 +536,7 @@ log_double_t move_subst_type_branch(Model& P)
     int B = PP.t().n_branches();
     for(int b=0;b<B;b++)
     {
-	int index = P.find_parameter("Main.branchCat" + convertToString(b+1));
-	int cat = P.get_parameter_value(index).as_int();
+	int cat = PP.get_branch_category(b);
 	if (cat == 1)
 	{
 	    assert(which_branch == -1);
@@ -639,27 +550,20 @@ log_double_t move_subst_type_branch(Model& P)
 	if (new_branch >= which_branch)
 	    new_branch++;
 
-	int index1 = P.find_parameter("Main.branchCat" + convertToString(which_branch+1));
-	int index2 = P.find_parameter("Main.branchCat" + convertToString(new_branch+1));
-
-	P.set_parameter_value(index1, 0);
-	P.set_parameter_value(index2, 1);
+	PP.set_branch_category(which_branch, 0);
+	PP.set_branch_category(new_branch, 1);
 	std::cerr<<"Moved subst type 1 from branch "<<which_branch<<" to branch "<<new_branch<<"\n";
     }
 
     return 1.0;
 }
 
-#include <boost/shared_ptr.hpp>
 #include "mcmc/sample.H"
 
 // Can't we just send in any sigma parameters or whatever WITH the proposal?
-boost::shared_ptr<DPmatrixSimple> sample_alignment_base(mutable_data_partition P, const indel::PairHMM& hmm, int b);
-boost::shared_ptr<DPmatrixSimple> sample_alignment_base(mutable_data_partition P, int b);
-boost::shared_ptr<DPmatrixSimple> sample_alignment_forward(data_partition P, const indel::PairHMM& hmm, int b);
 vector<int> walk_tree_path_toward(const TreeInterface& t, int root);
 
-log_double_t realign_and_propose_parameter(Model& P, int param, const vector<int>& partitions, const proposal_fn& proposal, const vector<double>& v)
+log_double_t realign_and_propose_parameter(context_ref& P, const vector<int>& partitions, const Proposal& propose)
 {
     Parameters& PP = dynamic_cast<Parameters&>(P);
     Parameters P0 = PP;
@@ -678,11 +582,7 @@ log_double_t realign_and_propose_parameter(Model& P, int param, const vector<int
     }
 
     // 2. Read, alter, and write parameter values
-    vector< expression_ref > x = P.get_parameter_values({param});
-
-    log_double_t ratio = proposal(x, v);
-
-    P.set_parameter_values({param},x);
+    auto ratio = propose(P);
 
     // 3. Realign all branches using the new parameter value
 
@@ -715,7 +615,7 @@ log_double_t realign_and_propose_parameter(Model& P, int param, const vector<int
 		}
 		{
 		    // Resample the alignment and calculate the proposal probability for the forward more.
-		    auto matrix_new = sample_alignment_base(PP[j], b);
+		    auto [matrix_new,_] = sample_alignment_base(PP[j], b);
 		    auto a_new = PP[j].get_pairwise_alignment(b);
 		    vector<int> path_new = A2::get_path_from_pairwise_alignment(a_new);
 
