@@ -173,7 +173,7 @@ vector<pair<string,dynamic_bitset<>>> get_branch_queries_from_tree(SequenceTree
             auto split = branch_partition(Q,b);
             groups.push_back({name, split});
 
-            if (log_verbose)
+            if (log_verbose >= 2)
             {
                 std::cerr<<name<<" = ";
                 for(int i=0;i<split.size();i++)
@@ -612,6 +612,7 @@ variables_map parse_cmd_line(int argc,char* argv[])
         ("alignments,A", value<vector<string>>()->composing(),"File of alignment samples")
         ("trees,T", value<vector<string>>()->composing(), "File of corresponding tree samples")
         ("subsample,x",value<unsigned>()->default_value(10),"factor by which to sub-sample trees")
+        ("max,m",value<unsigned>()->default_value(500),"Thin (alignment,tree) pairs down to this number of samples.")
         ;
 
     options_description ancestors("Ancestor query options");
