@@ -25,18 +25,23 @@
 #include <map>
 #include <cmath>
 #include <fstream>
-#include "matrix.H"
+#include "util/matrix.H"
+#include "util/io/matrix.H"
 #include "statistics.H"
 
 #include "tree/sequencetree.H"
-#include "util.H"
+#include "util/string/join.H"
+#include "util/string/convert.H"
+#include "util/cmdline.H"
 #include "tree/tree-util.H"
 #include "tree-dist.H"
-#include "rng.H"
+#include "util/rng.H"
 
 #include <boost/program_options.hpp>
 #include "distance-report.H"
 
+extern int log_verbose;
+
 namespace po = boost::program_options;
 using po::variables_map;
 
@@ -50,18 +55,7 @@ using std::endl;
 using std::cout;
 using std::cerr;
 
-using boost::optional;
-
-template <typename T>
-void print_matrix(const matrix<T>& M, char space=' ', char eol='\n')
-{
-    for(int i=0;i<M.size1();i++) {
-	vector<double> v(M.size2());
-	for(int j=0;j<v.size();j++)
-	    v[j] = M(i,j);
-	cout<<join(v,space)<<eol;
-    }
-}
+using std::optional;
 
 matrix<double> remove_duplicates(const matrix<double>& D)
 {
@@ -131,7 +125,7 @@ variables_map parse_cmd_line(int argc,char* argv[])
 	("until,u",value<int>(),"Read until this number of trees.")
 	("max,m",value<int>(),"Thin tree samples down to this number of trees.")
 	("subsample,x",value<int>()->default_value(1),"factor by which to subsample")
-	("verbose,v","Output more log messages on stderr.")
+	("verbose,V","Output more log messages on stderr.")
 	;
 
     options_description analysis("Analysis options");
@@ -733,7 +727,7 @@ int main(int argc,char* argv[])
 		    for(int j=0;j<D.size2();j++)
 			D(i,j) += gaussian(0,sigma);
 	    }
-	    print_matrix(D,'\t','\n');
+	    print_matrix(std::cout,D,'\t','\n');
 	}
 
 	else if (analysis == "autocorrelation") 
