@@ -1,6 +1,7 @@
 {-# LANGUAGE RecursiveDo #-}
 import           Probability
 import           Tree
+import           Tree.Newick
 
 main = random $ do
     tree <- uniform_topology 5
@@ -12,5 +13,6 @@ main = random $ do
                 Nothing   -> 0.0
                 Just node -> xs !! node
         xs <- independent [ normal (mu node) 1.0 | node <- nodes rtree ]
+    -- can we _observe_ from this? -- why or why not?
 
     return ["tree" %=% write_newick rtree, "xs" %=% xs, "ps" %=% ps]
